# airo-typing

python package with common types that are used across multiple other packages.

These types also define some of our conventions such as the use of scalar-last quaternions or metric units.